@@ -208,7 +208,8 @@ def input_filter(input_dict):
         filtered_dict["self_loop"] = 1
     if filtered_dict["multigraph"] not in [1, 2]:
         filtered_dict["multigraph"] = 1
-    if filtered_dict["output_format"] not in list(range(1, 12)):
+    if filtered_dict["output_format"] not in list(
+            range(1, len(SUFFIX_MENU) + 1)):
         filtered_dict["output_format"] = 1
     return filtered_dict
 
@@ -993,6 +994,65 @@ def tgf_maker(
     return edge_number
 
 
+def gl_maker(
+        file_name,
+        min_weight,
+        max_weight,
+        vertices,
+        min_edge,
+        max_edge,
+        sign,
+        direct,
+        self_loop,
+        multigraph):
+    """
+    Create output file in Graph Line(GL).
+
+    :param file_name: file name
+    :type file_name: str
+    :param min_weight: weight min range
+    :type min_weight: int
+    :param max_weight: weight max range
+    :type max_weight: int
+    :param vertices: number of vertices
+    :type vertices: int
+    :param min_edge : minimum edge number
+    :type min_edge : int
+    :param max_edge : maximum edge number
+    :type max_edge : int
+    :param sign: weight sign flag
+    :type sign: int
+    :param direct: directed and undirected graph flag
+    :type direct: int
+    :param self_loop: self loop flag
+    :type self_loop: int
+    :param multigraph: multigraph flag
+    :type multigraph: int
+    :return: edge_number as int
+    """
+    file = open(file_name + ".gl", "w")
+    dicts = edge_gen(
+        vertices,
+        min_weight,
+        max_weight,
+        min_edge,
+        max_edge,
+        sign,
+        direct,
+        self_loop,
+        multigraph)
+    edge_dic = dicts[0]
+    weight_dic = dicts[1]
+    edge_number = dicts[2]
+    for i in edge_dic.keys():
+        line_data = str(i)
+        for j, value in enumerate(edge_dic[i]):
+            line_data += " " + str(value) + ":" + str(weight_dic[i][j])
+        file.write(line_data + "\n")
+    file.close()
+    return edge_number
+
+
 def dl_maker(
         file_name,
         min_weight,
@@ -1052,6 +1112,148 @@ def dl_maker(
     return edge_number
 
 
+def gdf_maker(
+        file_name,
+        min_weight,
+        max_weight,
+        vertices,
+        min_edge,
+        max_edge,
+        sign,
+        direct,
+        self_loop,
+        multigraph):
+    """
+    Create output file in GDF Format.
+
+    :param file_name: file name
+    :type file_name: str
+    :param min_weight: weight min range
+    :type min_weight: int
+    :param max_weight: weight max range
+    :type max_weight: int
+    :param vertices: number of vertices
+    :type vertices: int
+    :param min_edge : minimum edge number
+    :type min_edge : int
+    :param max_edge : maximum edge number
+    :type max_edge : int
+    :param sign: weight sign flag
+    :type sign: int
+    :param direct: directed and undirected graph flag
+    :type direct: int
+    :param self_loop: self loop flag
+    :type self_loop: int
+    :param multigraph: multigraph flag
+    :type multigraph: int
+    :return: edge_number as int
+    """
+    file = open(file_name + ".gdf", "w")
+    dicts = edge_gen(
+        vertices,
+        min_weight,
+        max_weight,
+        min_edge,
+        max_edge,
+        sign,
+        direct,
+        self_loop,
+        multigraph)
+    edge_dic = dicts[0]
+    weight_dic = dicts[1]
+    edge_number = dicts[2]
+    file.write("nodedef>name VARCHAR,label VARCHAR\n")
+    for i in edge_dic.keys():
+        file.write(str(i) + "," + "Node{0}".format(str(i)) + "\n")
+    file.write("edgedef>node1 VARCHAR,node2 VARCHAR,weight DOUBLE\n")
+    for i in edge_dic.keys():
+        for j, value in enumerate(edge_dic[i]):
+            file.write(str(i) + "," + str(value) + "," +
+                       str(weight_dic[i][j]) + "\n")
+    file.close()
+    return edge_number
+
+
+def gml_maker(
+        file_name,
+        min_weight,
+        max_weight,
+        vertices,
+        min_edge,
+        max_edge,
+        sign,
+        direct,
+        self_loop,
+        multigraph):
+    """
+    Create output file in GML Format.
+
+    :param file_name: file name
+    :type file_name: str
+    :param min_weight: weight min range
+    :type min_weight: int
+    :param max_weight: weight max range
+    :type max_weight: int
+    :param vertices: number of vertices
+    :type vertices: int
+    :param min_edge : minimum edge number
+    :type min_edge : int
+    :param max_edge : maximum edge number
+    :type max_edge : int
+    :param sign: weight sign flag
+    :type sign: int
+    :param direct: directed and undirected graph flag
+    :type direct: int
+    :param self_loop: self loop flag
+    :type self_loop: int
+    :param multigraph: multigraph flag
+    :type multigraph: int
+    :return: edge_number as int
+    """
+    file = open(file_name + ".gml", "w")
+    dicts = edge_gen(
+        vertices,
+        min_weight,
+        max_weight,
+        min_edge,
+        max_edge,
+        sign,
+        direct,
+        self_loop,
+        multigraph)
+    edge_dic = dicts[0]
+    weight_dic = dicts[1]
+    edge_number = dicts[2]
+    header = 'graph\n[\n  multigraph {0}\n  directed  {1}\n'
+    multigraph_flag = str(int(abs((1 - multigraph))))
+    directed_flag = str(int(2 - direct))
+    header = header.format(multigraph_flag, directed_flag)
+    file.write(header)
+    for i in edge_dic.keys():
+        file.write(
+            "  node\n  [\n   id " +
+            str(i) +
+            "\n" +
+            '   label "Node {0}"\n'.format(
+                str(i)) +
+            "  ]\n")
+    for i in edge_dic.keys():
+        for j, value in enumerate(edge_dic[i]):
+            file.write("  edge\n  [\n   source " +
+                       str(i) +
+                       "\n" +
+                       "   target " +
+                       str(value) +
+                       "\n" +
+                       "   value " +
+                       str(weight_dic[i][j]) +
+                       "\n" +
+                       "  ]\n")
+    file.write("]")
+    file.close()
+    return edge_number
+
+
 def print_test(a):
     """
     Added for get_input parameter injection testing.
